diff src/account.h @ 11249:b4b1be482b4e

[gaim-migrate @ 13418] sf patch #1235519, from Sadrul Habib Chowdhury This is a pretty big patch that makes Gaim correctly save and restore the current status (away/available, away message, available message, invisible, etc). The GaimGtkStatusBoxWidget thing I think defaults to "Available" every time its created, which overrides the setting that was saved to the XML file. So that still needs to be fixed before this will really work. Anyway, mad props to Sadrul for putting up with my requests on this patch committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Sat, 13 Aug 2005 05:22:09 +0000
parents bd8ac1d4b2f2
children ad9a61894d9b
line wrap: on
line diff
--- a/src/account.h	Sat Aug 13 03:55:07 2005 +0000
+++ b/src/account.h	Sat Aug 13 05:22:09 2005 +0000
@@ -274,7 +274,8 @@
 
 /**
  * Activates or deactivates a status.  All changes to the statuses of
  * an account go through this function or gaim_account_set_status_vargs.
  *
  * Only independent statuses can be deactivated with this. To deactivate
  * an exclusive status, activate a different (and exclusive?) status.
@@ -291,7 +292,8 @@
 
 /**
  * Activates or deactivates a status.  All changes to the statuses of
  * an account go through this function or gaim_account_set_status.
  *
  * Only independent statuses can be deactivated with this. To deactivate
  * an exclusive status, activate a different (and exclusive?) status.
@@ -306,6 +308,23 @@
 								   gboolean active, va_list args);
 
 /**
+ * Activates or deactivates a status.  All changes to the statuses of
+ * an account go through this function or gaim_account_set_status or
+ * gaim_account_set_status_vargs.
+ *
+ * Only independent statuses can be deactivated with this. To deactivate
+ * an exclusive status, activate a different (and exclusive?) status.
+ *
+ * @param account   The account.
+ * @param status_id The ID of the status.
+ * @param active    The active state.
+ * @param attrs		A list of attributes in key/value pairs
+ */
+void gaim_account_set_status_list(GaimAccount *account,
+								  const char *status_id,
+								  gboolean active, GList *attrs);
+
+/**
  * Clears all protocol-specific settings on an account.
  *
  * @param account The account.
@@ -274,7 +274,8 @@
 /**
  * Activates or deactivates a status.  All changes to the statuses of
- * an account go through this function or gaim_account_set_status_vargs.
+ * an account go through this function or gaim_account_set_status_vargs
+ * or gaim_account_set_status_list.
  *
  * Only independent statuses can be deactivated with this. To deactivate
@@ -291,7 +292,8 @@
 /**
  * Activates or deactivates a status.  All changes to the statuses of
- * an account go through this function or gaim_account_set_status.
+ * an account go through this function or gaim_account_set_status or
+ * gaim_account_set_status_list.
  *
  * Only independent statuses can be deactivated with this. To deactivate